@@ -34,6 +34,8 @@ const validParametersKeys = [
   'references',
   'summary',
   'value',
+  'site',
+  'badges',
 ]
 
 const validParametersKeysSet = new Set(validParametersKeys)
