@@ -1,7 +1,7 @@
 const { forceArray } = require('../utils')
 const validate = require('../validate')
 const error_ = require('../error')
-const getEntityClaims = require('./get_entity_claims')
+const { getEntityClaims } = require('../get_entity')
 const isMatchingClaim = require('./is_matching_claim')
 const buildClaim = require('../entity/build_claim')
 
