@@ -1,7 +1,7 @@
 const { isEntityId } = require('wikibase-sdk')
 const error_ = require('../error')
 const format = require('./format')
-const getEntityClaims = require('../claim/get_entity_claims')
+const { getEntityClaims } = require('../get_entity')
 const { forceArray } = require('../utils')
 const { isIdAliasPattern, resolveIdAlias } = require('./id_alias')
 
