@@ -2,13 +2,14 @@ const validate = require('../validate')
 const error_ = require('../error')
 
 module.exports = name => params => {
-  const { id, language, value } = params
+  const { id, language } = params
+  let { value } = params
   const action = `wbset${name}`
 
   validate.entity(id)
   validate.language(language)
-  if (value == null) throw error_.new(`missing ${name}`, params)
-  validate.labelOrDescription(name, value)
+  if (value === undefined) throw error_.new(`missing ${name}`, params)
+  if (value === null) value = ''
 
   return {
     action,
