@@ -35,5 +35,8 @@ module.exports = {
   },
   values: obj => Object.keys(obj).map(key => obj[key]),
   uniq: array => Array.from(new Set(array)),
+  difference: (values, excluded) => {
+    return values.filter(value => !excluded.includes(value))
+  },
   wait: ms => new Promise(resolve => setTimeout(resolve, ms))
 }
